package Pcore::GeoIP v1.2.0;

use Pcore -dist;

# register Pcore util
$Pcore::UTIL->{geoip} = 'Pcore::Util::GeoIP';

1;
__END__
=pod

=encoding utf8

=head1 NAME

Pcore::GeoIP

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 ATTRIBUTES

=head1 METHODS

=head1 SEE ALSO

=head1 AUTHOR

zdm <zdm@softvisio.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by zdm.

=cut
